#!/bin/sh
echo 'name: parsec
version: 3.1.3
id: parsec-3.1.3-fb970d7908f363dfef34b141200235e6

license: BSD3
copyright:
maintainer: Antoine Latter <aslatter@gmail.com>
stability:
homepage: http://www.cs.uu.nl/~daan/parsec.html
package-url:
synopsis: Monadic parser combinators
description: Parsec is designed from scratch as an industrial-strength parser
             library.  It is simple, safe, well documented (on the package
             homepage), has extensive libraries and good error messages,
             and is also fast.  It is defined as a monad transformer that can be
             stacked on arbitrary monads, and it is also parametric in the
             input stream type.
category: Parsing
author: Daan Leijen <daan@microsoft.com>, Paolo Martini <paolo@nemail.it>
pkgpath: devel/hs-parsec
exposed: True
exposed-modules: Text.Parsec Text.Parsec.String
                 Text.Parsec.ByteString Text.Parsec.ByteString.Lazy Text.Parsec.Text
                 Text.Parsec.Text.Lazy Text.Parsec.Pos Text.Parsec.Error
                 Text.Parsec.Prim Text.Parsec.Char Text.Parsec.Combinator
                 Text.Parsec.Token Text.Parsec.Expr Text.Parsec.Language
                 Text.Parsec.Perm Text.ParserCombinators.Parsec
                 Text.ParserCombinators.Parsec.Char
                 Text.ParserCombinators.Parsec.Combinator
                 Text.ParserCombinators.Parsec.Error
                 Text.ParserCombinators.Parsec.Expr
                 Text.ParserCombinators.Parsec.Language
                 Text.ParserCombinators.Parsec.Perm
                 Text.ParserCombinators.Parsec.Pos
                 Text.ParserCombinators.Parsec.Prim
                 Text.ParserCombinators.Parsec.Token
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/parsec-3.1.3
library-dirs: /usr/local/lib/ghc/parsec-3.1.3
hs-libraries: HSparsec-3.1.3
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
         text-0.11.2.3-6d44323283fc0f3935743a72b4424942
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-parsec-3.1.3/html/parsec.haddock
haddock-html: /usr/local/share/doc/hs-parsec-3.1.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
